package reversie1_1.server.corba;

import reversie1_1.client.corba.RevClient;

public interface RevServer
{
  // registered user login
  // returns a positive ID to be used for this session
  // or -1 if login failed
  //
  // adds clRef to the list of logged users and assigns
  // an id to be used for identification of the client
  // only for the period of this session
  short logUser(
          String name,
          String password,
          RevClient clRef
  );

  // guest login
  // returns a positive ID to be used only for this session
  // as a unique user ID
  //
  // adds clRef to the list of logged users and assigns
  // an id to be used for identification of the client
  // only for the period of this session
  short logGuest(
          RevClient clRef
  );

  // create a new user, given a guest (by argument id)
  // returns true if no name clashes, false if that name already exists
  //
  // adds name and password to the list of all users known by
  // the server
  boolean createUser(
          String name,
          String password,
          short id
  );

  // logout method, log out the user identified by 'id'
  // delete this user's reference from the list of logged
  // users and release this id for uses with other clients
  // careful if the id is wrong, i.e. not assigned to any
  // logged user
  void logout(
          short id
  );

  // suggestions and remarks
  // - the list of logged users should be implemented as an array
  //   the id has type 'short' to be generated as an index in this
  //   array
  //
  // - the list of users should be implemented as a hashtable,
  //   provided in java.util.Hashtable
  //
  // - the interface reversie1_1.client.corba.RevClient is
  //   an empty java interface for the moment
}
