// modify this file to get the implementation of the client object

package reversie1_1.client;

import reversie1_1.client.corba.*;
import reversie1_1.server.corba.RevServer;

public class _RevClientImpl extends _RevClientImplBase
{
  protected RevServer server_;
  
  public short status_;
  public short id_;	
  
  final short NOTLOGGED = 1;
  final short LOGGEDASGUEST = 2;
  final short LOGGEDASUSER = 3;
  
  
  // stores the server object
  
  public _RevClientImpl(RevServer server)
    {
      server_ = server;
      status_ = NOTLOGGED;
    }
  
  // the GUI calls this method with a name and a password
  // if the name is "guest", then call logGuest on server
  // otherwise call logUser on server
  // return true if the login was successful
  // if login is succesful change state of the client to
  // one of the other two
  // login should only work if the current state is (not logged)
  
  public boolean login(String name, String password)
    {
      if (status_ == NOTLOGGED)
	{
	  if (name.equals("guest"))
	    {
	      if((id_=server_.logGuest(this))>=0)
		{
		  status_=LOGGEDASGUEST;
		}
	    }
	  else
	    { 
	      if((id_=server_.logUser(name, password, this)) >= 0)
		{
		  status_=LOGGEDASUSER;
		}
	    }
	  return (id_ >= 0);	
	}
      else
	{
	  // can't login
	  return false;
	}
    }
  
  // if the client is currently logged as a guest return true
  // basically it returns true if the current state is
  // (logged as guest)
  
  public boolean isGuest()
    {
      return status_ == LOGGEDASGUEST;
    }
  
  // call createUser on server to register this new user
  // return true if successful, and change state to
  // registered as user
  // it should only work if the current state is
  // (logged as guest)
  
  public boolean register(String name, String password)
    {
      if (status_ == LOGGEDASGUEST)
	{
	  if (server_.createUser(name, password, id_))
	    {
	      status_= LOGGEDASUSER;	
	      return(true);
	    }
	  else
	    {
	      return(false);
	    }	
	}
      else
	{
	  //not guest, can't register
	  return false;
	}
      
    }
  
  // call logout method on server
  // it should only work if the client is currently
  // in the state (logged as user) or (logged as guest)
  
  public void logout()
    {
      if ((status_ == LOGGEDASGUEST) || (status_ == LOGGEDASUSER))
	{
	  server_.logout(id_);
	  status_=NOTLOGGED;
	}
      else
	{
	  // not login, can't logout
	  // System.out.println("can't logout");
	}
    }
  
  // remarks
  // - look carefully at the server interface and make sure
  //   you understand it's functionality, because the client
  //   will call the server object
  // - even though the server object is a remote object
  //   it can be treated as a local one, due to CORBA
  // - please notice that the server object is passed
  //   as an argument in the constructor and stored
}
